%define with_maven 0
%define with_repolib 1
%define pkg_version %(echo %version | tr . _ )
%if %with_repolib
%define repodir %{_javadir}/repository.jboss.com/org/apache/%{version}-brew
%define repodirlib %{repodir}/lib
%define repodirsrc %{repodir}/src
%define compatrepodir %{_javadir}/repository.jboss.com/apache-xmlsec/%{version}-brew
%endif

Name:          xml-security-j
Version:       1.4.3
Release:       %mkrel 1
Summary:       Java Implementation of W3C security standards for XML​
Group:         Development/Java
License:       ASL
Url:           http://santuario.apache.org/
Source0:       http://archive.apache.org/dist/santuario/java-library/xml-security-src-%{pkg_version}.zip
# from http://svn.apache.org/viewvc/santuario/xml-security-java/tags/J_1_4_3/
Source1:       xml-security-j-%{version}-pom
Source2:       xml-security-j-%{version}-OSGi-MANIFEST.tar.gz
Source3:       xml-security-j-component-info.xml
Source4:       xml-security-j-%{version}-documentation.tar.gz
Patch0:        xml-security-j-1.4.3-add_osgi_manifest.patch
%if !%with_maven
BuildRequires: ant
BuildRequires: batik
BuildRequires: avalon-framework
BuildRequires: avalon-logkit
BuildRequires: servletapi4
%else
BuildRequires: maven
BuildRequires: maven-compiler-plugin
BuildRequires: maven-plugin-bundle
BuildRequires: maven-site-plugin
BuildRequires: maven-skins
BuildRequires: maven-source-plugin
BuildRequires: maven-surefire-plugin
%endif
BuildRequires: apache-commons-logging
BuildRequires: java-devel
BuildRequires: jpackage-utils
BuildRequires: junit
BuildRequires: liblog4j-java
BuildRequires: xalan-j2
BuildRequires: xerces-j2
BuildRequires: xml-commons-apis
Requires:      apache-commons-logging
Requires:      jpackage-utils
Requires:      liblog4j-java
Requires:      xalan-j2
Requires:      xerces-j2
Requires:      xml-commons-apis
BuildArch:     noarch

%description
Apache XML Security supports XML-Signature Syntax and Processing,
W3C Recommendation 12 February 2002, and XML Encryption Syntax and
Processing, W3C Recommendation 10 December 2002. As of version 1.4,
the Java library supports the standard Java API JSR-105: XML Digital
Signature APIs.

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}
Requires:      %{name} = %{version}-%{release} 
Requires:      jpackage-utils

%description javadoc
Java Implementation of W3C security standards for XML​.

This package contains javadoc for %{name}.

%if %with_repolib
%package repolib
Group:          Development/Java
Summary:        Artifacts to be uploaded to a repository library

%description repolib
Artifacts to be uploaded to a repository library.
This package is not meant to be installed but so its contents
can be extracted through rpm2cpio.
%endif

%prep
%setup -q -n xml-security-%{pkg_version}
chmod -R go=u-w *

for j in $(find . -name "*.jar"); do
  rm -rf $j
done

cp -pr %{SOURCE1} pom.xml

%if !%with_maven
  pushd libs
    ln -sf $(build-classpath xml-commons-apis) xml-apis.jar
    ln -sf $(build-classpath xerces-j2) xercesImpl.jar
    ln -sf $(build-classpath xalan-j2) xalan.jar
    ln -sf $(build-classpath xalan-j2-serializer) serializer.jar
    ln -sf $(build-classpath commons-logging) commons-logging.jar
    ln -sf $(build-classpath commons-logging-api) commons-logging-api.jar
    ln -sf $(build-classpath log4j) .
    ln -sf $(build-classpath junit) junit.jar
  popd

%patch0 -p0

  mkdir -p build/classes
  (
    cd build/classes
    tar xf %{SOURCE2}
  )
  mkdir -p doc/site/build/site
# require apache forrest and .. need .. for build apache harmony
  cd doc/site/build/site
  tar xf %{SOURCE4}
%endif

%build
%if %with_maven

  export MAVEN_REPO_LOCAL=$PWD/.m2/repository
  mkdir -p $MAVEN_REPO_LOCAL

  mvn-jpp \
    -e \
    -Dmaven2.jpp.mode=true \
    -Dmaven.test.skip=true \
    -Dmaven.repo.local=$MAVEN_REPO_LOCAL \
    install javadoc:javadoc

%else
export CLASSPATH=""
CLASSPATH=$CLASSPATH:$(build-classpath log4j junit commons-logging-api commons-logging batik-all)
CLASSPATH=$CLASSPATH:$(build-classpath xalan-j2 xalan-j2-serializer xerces-j2 xml-commons-apis)
CLASSPATH=$CLASSPATH:$(build-classpath ant avalon-logkit avalon-framework servletapi4)

ant \
  -Dlib.jce=%java_home/jre/lib/jce.jar \
  build.bindist

%endif

%install
[ %{buildroot} != / ] && rm -rf %{buildroot}

mkdir -p %{buildroot}%{_javadir}
%if %with_maven
install -m 644 target/xmlsec-%{version}-SNAPSHOT.jar \
  %{buildroot}%{_javadir}/xml-security-%{version}.jar
%else
install -m 644 build/xmlsec-%{version}.jar \
  %{buildroot}%{_javadir}/xml-security-%{version}.jar
install -m 644 build/xmlsecSamples-%{version}.jar \
  %{buildroot}%{_javadir}/xml-security-samples-%{version}.jar
 ln -s xml-security-samples-%{version}.jar %{buildroot}%{_javadir}/xmlsecSamples-%{version}.jar
%endif

mkdir -p %{buildroot}%{_mavenpomdir}
install -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-xml-security.pom
%add_to_maven_depmap org.apache xmlsec %{version} JPP xml-security
%add_to_maven_depmap org.apache.santuario xmlsec %{version} JPP xml-security
mv %{buildroot}%{_mavendepmapfragdir}/xml-security-j %{buildroot}%{_mavendepmapfragdir}/xml-security

(
  cd %{buildroot}%{_javadir}
  for jar in *-%{version}*; do
    ln -sf ${jar} ${jar/-%{version}/}
  done
)

mkdir -p %{buildroot}%{_javadocdir}/xml-security-%{version}
%if %with_maven
cp -pr target/site/apidocs/* %{buildroot}%{_javadocdir}/xml-security-%{version}
%else
cp -pr build/docs/html/javadoc/* %{buildroot}%{_javadocdir}/xml-security-%{version}
%endif
ln -s xml-security-%{version} %{buildroot}%{_javadocdir}/xml-security

%if %with_repolib
mkdir -p %{buildroot}%{repodir}
mkdir -p  %{buildroot}%{repodirlib}
install -m 644 %{SOURCE3} %{buildroot}%{repodir}/component-info.xml
tag=`echo xml-security-%{version}-%{release} | sed 's|\.|_|g'`
sed -i "s/@TAG@/$tag/g" %{buildroot}%{repodir}/component-info.xml
sed -i "s/@VERSION@/%{version}-brew/g" %{buildroot}%{repodir}/component-info.xml
mkdir -p %{buildroot}%{repodirsrc}
install -pm 644 build/xml-security-bin-%{pkg_version}.zip %{buildroot}%{repodirsrc}
#install -pm 644 %{SOURCE0} %{buildroot}%{repodirsrc}
install -pm 644 %{SOURCE1} %{buildroot}%{repodirsrc}/pom.xml
cp -p %{buildroot}%{_javadir}/xml-security-%{version}.jar %{buildroot}%{repodirlib}/xmlsec.jar
mkdir -p %{buildroot}%{compatrepodir}/
ln -s %{repodir}/lib %{buildroot}%{compatrepodir}/lib
ln -s %{repodir}/src %{buildroot}%{compatrepodir}/src
cp -a %{buildroot}%{repodir}/component-info.xml %{buildroot}%{compatrepodir}/component-info.xml
sed -i s,org/apache,apache-xmlsec, %{buildroot}%{compatrepodir}/component-info.xml
%endif

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_javadir}/xml-security-%{version}.jar
%{_javadir}/xml-security.jar
%if !%with_maven
%{_javadir}/xml-security-samples-%{version}.jar
%{_javadir}/xml-security-samples.jar
%{_javadir}/xmlsecSamples-%{version}.jar
%{_javadir}/xmlsecSamples.jar
%endif
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%doc LICENSE NOTICE Readme.html TODO

%files javadoc
%{_javadocdir}/xml-security-%{version}
%{_javadocdir}/xml-security

%if %with_repolib
%files repolib
%{repodir}/*
%{compatrepodir}/*
%endif



%changelog
* Thu Aug 11 2011 dmorgan <dmorgan> 1.4.3-1.mga2
+ Revision: 132705
- Clean spec file

  + gil <gil>
    - imported package xml-security-j


* Tue Jun 28 2011 gil <gil> 1.4.3-0.%%mkrel
- initial rpm
